class Model:
  
  def __init__(self):
    self.model = ""
    
  def get_training_data(self):
      from sklearn.datasets import load_iris
      X, y = load_iris(return_X_y = True)
      return X, y

  def format_input(self, X):
      return X
  
  def fit_model(self, X, y):
      from sklearn.neighbors import KNeighborsClassifier
      X = self.format_input(X)
      model = KNeighborsClassifier()
      model.fit(X, y)
      return model
 
  def build_model(self):
      X, y = self.get_training_data()
      model = self.fit_model(X, y)
      setattr(self, "model", model)
      return "Model was successfully build"
      
  def predict(self, X):
      X = self.format_input(X)
      model = self.model
      preds = model.predict(X)
      return preds

  def parse_input(self, json):
      import numpy as np
      samples = [np.array(list(obs.values()), ndmin = 2) for obs in json]
      samples = np.concatenate(samples, axis = 0)
      return(samples)
    
  def parse_output(self, preds):
      preds_out = preds.tolist()
      preds_json = {'predictions': preds_out}
      return preds_json





import setuptools

with open("README.md", "r") as fh:
    long_description = fh.read()

setuptools.setup(
    name="newspick", 
    version="0.0.1",
    author="Lars Kjeldgaard",
    author_email="lars_kjeldgaard@hotmail.com",
    description="Slim Iris Model",
    long_description=long_description,
    long_description_content_type="text/markdown",
    packages=setuptools.find_packages(where='src'),
    package_dir={'': 'src'},
    install_requires=[
        'sklearn',
        'numpy'
    ],
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    python_requires='>=3.6',
    include_package_data=True
    )
